@@ -44,6 +44,7 @@
 #include "gnc-engine.h"
 #include "gnc-prefs.h"
 #include "gnc-uri-utils.h"
+#include "gnc-gtk-utils.h"
 
 static GObjectClass *parent_class = NULL;
 
@@ -65,12 +66,12 @@ static void gnc_plugin_file_history_remove_from_window (GncPlugin *plugin, GncMa
 static QofLogModule log_module = GNC_MOD_GUI;
 
 /* Command callbacks */
-static void gnc_plugin_file_history_cmd_open_file (GtkAction *action, GncMainWindowActionData *data);
+static void gnc_plugin_file_history_cmd_open_file (GSimpleAction *simple, GVariant *parameter, gpointer user_data);
 
 /** The label given to the main window for this plugin. */
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-file-history-actions"
 /** The name of the UI description file for this plugin. */
-#define PLUGIN_UI_FILENAME  "gnc-plugin-file-history-ui.xml"
+#define PLUGIN_UI_FILENAME  "gnc-plugin-file-history.ui"
 
 #define GNOME1_HISTORY "History"
 #define GNOME1_MAXFILES "MaxFiles"
@@ -80,22 +81,27 @@ static void gnc_plugin_file_history_cmd_open_file (GtkAction *action, GncMainWin
  *  will be updated to reflect the users recent choices.  This list is
  *  limited to ten actions, although there may be a smaller limit set
  *  by the user.  The typical limit is four. */
-static GtkActionEntry gnc_plugin_actions [] =
+static GActionEntry gnc_plugin_actions [] =
 {
-    { "RecentFile0Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile1Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile2Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile3Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile4Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile5Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile6Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile7Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile8Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
-    { "RecentFile9Action", NULL, "", NULL, NULL, G_CALLBACK (gnc_plugin_file_history_cmd_open_file) },
+    { "RecentFile0Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile1Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile2Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile3Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile4Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile5Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile6Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile7Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile8Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
+    { "RecentFile9Action", gnc_plugin_file_history_cmd_open_file, NULL, NULL, NULL },
 };
 /** The number of actions provided by this plugin. */
-static guint gnc_plugin_n_actions = G_N_ELEMENTS (gnc_plugin_actions);
+static guint gnc_plugin_n_actions = G_N_ELEMENTS(gnc_plugin_actions);
 
+/** The default menu items that need to be add to the menu */
+static const gchar *gnc_plugin_load_ui_items [] =
+{
+    NULL,
+};
 
 /** The instance private data for a file history plugin.  This data
  *  structure is unused. */
@@ -407,46 +413,64 @@ gnc_history_update_action (GncMainWindow *window,
                            gint index,
                            const gchar *filename)
 {
-    GtkActionGroup *action_group;
-    GtkAction *action;
-    gchar *action_name, *label_name, *tooltip, *old_filename;
+    GncMenuModelSearch *gsm = g_new0 (GncMenuModelSearch, 1);
+    gchar *action_name;
     gint limit;
+    gboolean add_item = FALSE;
+    gint pos;
 
     ENTER("window %p, index %d, filename %s", window, index,
           filename ? filename : "(null)");
-    /* Get the action group */
-    action_group =
-        gnc_main_window_get_action_group(window, PLUGIN_ACTIONS_NAME);
 
-    action_name = g_strdup_printf("RecentFile%dAction", index);
-    action = gtk_action_group_get_action (action_group, action_name);
+    action_name = g_strdup_printf ("RecentFile%dAction", index);
+
+    gsm->search_action_label = NULL;
+    gsm->search_action_name = action_name;
+
+    if (!gnc_menubar_model_find_item (gnc_main_window_get_menu_model(window), gsm)) // could not find action_name
+    {
+        add_item = TRUE;
+        gsm->search_action_name = "FilePlaceholder6"; // placeholder
+
+        if (!gnc_menubar_model_find_item (gnc_main_window_get_menu_model(window), gsm))
+        {
+            LEAVE("Could not find 'menu_item' with action name '%s'", action_name);
+            g_free (gsm);
+            g_free (action_name);
+            return;
+        }
+        else
+            pos = gsm->index + index;
+    }
+    else
+        pos = gsm->index;
 
     limit = gnc_prefs_get_int (GNC_PREFS_GROUP_HISTORY,
                                GNC_PREF_HISTORY_MAXFILES);
 
     if (filename && (strlen(filename) > 0) && (index < limit))
     {
-        /* set the menu label (w/accelerator) */
-        label_name = gnc_history_generate_label(index, filename);
-        tooltip    = gnc_history_generate_tooltip(index, filename);
-        g_object_set(G_OBJECT(action), "label", label_name,
-                                       "tooltip", tooltip,
-                                       "visible", TRUE,
-                                       NULL);
-        g_free(label_name);
-        g_free(tooltip);
+        GMenuItem *item;
+        gchar *label_name = gnc_history_generate_label (index, filename);
+        gchar *tooltip = gnc_history_generate_tooltip (index, filename);
+        gchar *full_action_name = g_strconcat (PLUGIN_ACTIONS_NAME, ".",
+                                               action_name, NULL);
 
-        /* set the filename for the callback function */
-        old_filename = g_object_get_data(G_OBJECT(action), FILENAME_STRING);
-        if (old_filename)
-            g_free(old_filename);
-        g_object_set_data(G_OBJECT(action), FILENAME_STRING, g_strdup(filename));
+        item = g_menu_item_new (label_name, full_action_name);
+
+        g_menu_item_set_attribute (item, GNC_MENU_ATTRIBUTE_TOOLTIP, "s", tooltip);
+
+        if (!add_item)
+            g_menu_remove (G_MENU(gsm->model), pos);
+
+        g_menu_insert_item (G_MENU(gsm->model), pos, item);
+
+        g_free (full_action_name);
+        g_free (label_name);
+        g_free (tooltip);
     }
-    else
-    {
-        gtk_action_set_visible(action, FALSE);
-    }
-    g_free(action_name);
+    g_free (gsm);
+    g_free (action_name);
     LEAVE("");
 }
 
@@ -466,6 +490,7 @@ gnc_history_update_menus (GncMainWindow *window)
     guint i;
 
     ENTER("");
+
     for (i = 0; i < MAX_HISTORY_FILES; i++)
     {
         pref = gnc_history_index_to_pref_name(i);
@@ -518,7 +543,6 @@ gnc_plugin_history_list_changed (gpointer prefs,
     gnc_history_update_action (window, index, filename);
     g_free (filename);
 
-    gnc_main_window_actions_updated (window);
     LEAVE("");
 }
 
@@ -538,18 +562,18 @@ gnc_plugin_file_history_class_init (GncPluginFileHistoryClass *klass)
     object_class->finalize = gnc_plugin_file_history_finalize;
 
     /* plugin info */
-    plugin_class->plugin_name   = GNC_PLUGIN_FILE_HISTORY_NAME;
+    plugin_class->plugin_name = GNC_PLUGIN_FILE_HISTORY_NAME;
 
     /* function overrides */
     plugin_class->add_to_window = gnc_plugin_file_history_add_to_window;
-    plugin_class->remove_from_window =
-        gnc_plugin_file_history_remove_from_window;
+    plugin_class->remove_from_window = gnc_plugin_file_history_remove_from_window;
 
     /* widget addition/removal */
     plugin_class->actions_name  = PLUGIN_ACTIONS_NAME;
     plugin_class->actions       = gnc_plugin_actions;
     plugin_class->n_actions     = gnc_plugin_n_actions;
     plugin_class->ui_filename   = PLUGIN_UI_FILENAME;
+    plugin_class->ui_updates    = gnc_plugin_load_ui_items;
 }
 
 G_DEFINE_TYPE_WITH_PRIVATE(GncPluginFileHistory, gnc_plugin_file_history, GNC_TYPE_PLUGIN)
@@ -633,8 +657,8 @@ gnc_plugin_file_history_add_to_window (GncPlugin *plugin,
  */
 static void
 gnc_plugin_file_history_remove_from_window (GncPlugin *plugin,
-        GncMainWindow *window,
-        GQuark type)
+                                            GncMainWindow *window,
+                                            GQuark type)
 {
     gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_HISTORY, NULL,
                                  gnc_plugin_history_list_changed, window);
@@ -657,24 +681,37 @@ gnc_plugin_file_history_remove_from_window (GncPlugin *plugin,
  *  function and we're about to close all the windows anyway.
  */
 static void
-gnc_plugin_file_history_cmd_open_file (GtkAction *action,
-                                       GncMainWindowActionData *data)
+gnc_plugin_file_history_cmd_open_file (GSimpleAction *simple,
+                                       GVariant      *parameter,
+                                       gpointer       user_data)
+
 {
-    gchar *filename;
+    GncMainWindowActionData *data = user_data;
+    gchar *filename, *pref, *index;
+    const gchar *action_name;
 
-    g_return_if_fail(GTK_IS_ACTION(action));
-    g_return_if_fail(data != NULL);
+    g_return_if_fail (G_IS_SIMPLE_ACTION(simple));
+    g_return_if_fail (data != NULL);
+
+    // action name will be of the form 'RecentFile1Action'
+    action_name =  g_action_get_name (G_ACTION(simple));
+
+    index = g_utf8_substring (action_name, 10, 11);
+
+    pref = gnc_history_index_to_pref_name (atoi (index));
+    filename = gnc_prefs_get_string (GNC_PREFS_GROUP_HISTORY, pref);
+
+    PINFO("File to open is '%s' on action '%s'", filename, action_name);
 
-    /* DRH - Do we need to close all open windows but the first?
-     * Which progress bar should we be using? One in a window, or
-     * in a new "file loading" dialog???
-     */
-    filename = g_object_get_data(G_OBJECT(action), FILENAME_STRING);
     gnc_window_set_progressbar_window (GNC_WINDOW(data->window));
     /* also opens new account page */
     gnc_file_open_file (GTK_WINDOW (data->window),
                         filename, /*open_readonly*/ FALSE);
     gnc_window_set_progressbar_window (NULL);
+
+    g_free (pref);
+    g_free (filename);
+    g_free (index);
 }
 
 /** @} */
