@@ -73,6 +73,10 @@ typedef struct _PopBox
     gunichar complete_char; /* char to be used for auto-completion */
 
     GList* ignore_strings;
+
+    GHashTable *item_hash;
+
+    gboolean use_type_ahead_only;
 } PopBox;
 
 
@@ -163,6 +167,10 @@ gnc_combo_cell_init (ComboCell* cell)
     box->complete_char = '\0';
 
     box->ignore_strings = NULL;
+
+    box->item_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+
+    box->use_type_ahead_only = FALSE;
 }
 
 static void
@@ -324,8 +332,6 @@ gnc_combo_cell_destroy (BasicCell* bcell)
 
     if (box != NULL)
     {
-        GList* node;
-
         /* Don't destroy the qf if its not ours to destroy */
         if (FALSE == box->use_quickfill_cache)
         {
@@ -333,6 +339,9 @@ gnc_combo_cell_destroy (BasicCell* bcell)
             box->qf = NULL;
         }
 
+        if (box->item_hash)
+           g_hash_table_destroy (box->item_hash);
+
         g_list_free_full (box->ignore_strings, g_free);
         box->ignore_strings = NULL;
 
@@ -458,6 +467,64 @@ gnc_combo_cell_add_menu_item (ComboCell* cell, const char* menustr)
     }
 }
 
+void
+gnc_combo_cell_add_menu_item_unique (ComboCell* cell, const char* menustr)
+{
+    PopBox* box;
+
+    if (cell == NULL)
+        return;
+    if (menustr == NULL)
+        return;
+
+    box = cell->cell.gui_private;
+
+    if (box->item_list != NULL)
+    {
+        block_list_signals (cell);
+
+        /* check if menustr has already been added. */
+        if (g_hash_table_lookup_extended (box->item_hash, menustr, NULL, NULL))
+            return;
+
+        g_hash_table_insert (box->item_hash, g_strdup (menustr), NULL);
+
+        gnc_item_list_append (box->item_list, menustr);
+        if (cell->cell.value &&
+            (strcmp (menustr, cell->cell.value) == 0))
+            gnc_item_list_select (box->item_list, menustr);
+
+        unblock_list_signals (cell);
+    }
+    else
+    {
+        GtkTreeIter iter;
+
+        // add a blank entry as the first entry in store
+        if (gtk_tree_model_iter_n_children (GTK_TREE_MODEL(cell->shared_store), NULL) == 0)
+        {
+            gtk_list_store_append (cell->shared_store, &iter);
+            gtk_list_store_set (cell->shared_store, &iter, 0, "", -1);
+            g_hash_table_insert (box->item_hash, g_strdup (""), NULL);
+        }
+
+        /* check if menustr has already been added. */
+        if (g_hash_table_lookup_extended (box->item_hash, menustr, NULL, NULL))
+            return;
+
+        g_hash_table_insert (box->item_hash, g_strdup (menustr), NULL);
+        gtk_list_store_append (cell->shared_store, &iter);
+        gtk_list_store_set (cell->shared_store, &iter, 0, menustr, -1);
+    }
+
+    /* If we're going to be using a pre-fab quickfill,
+     * then don't fill it in here */
+    if (FALSE == box->use_quickfill_cache)
+    {
+        gnc_quickfill_insert (box->qf, menustr, QUICKFILL_ALPHA);
+    }
+}
+
 void
 gnc_combo_cell_add_account_menu_item (ComboCell* cell, char* menustr)
 {
@@ -536,7 +603,7 @@ gnc_combo_cell_type_ahead_search (const gchar* newval,
     GRegex* regex0 = g_regex_new (escaped_sep, 0, 0, NULL);
     char* rep_str = g_regex_replace_literal (regex0, escaped_newval, -1, 0,
                                              newval_rep, 0, NULL);
-    char* normal_rep_str = g_utf8_normalize (rep_str, -1, G_NORMALIZE_ALL);
+    char* normal_rep_str = g_utf8_normalize (rep_str, -1, G_NORMALIZE_NFC);
     GRegex *regex = g_regex_new (normal_rep_str, G_REGEX_CASELESS, 0, NULL);
 
     gboolean valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (full_store),
@@ -565,7 +632,7 @@ gnc_combo_cell_type_ahead_search (const gchar* newval,
         gchar* normalized_str_data = NULL;
         gtk_tree_model_get (GTK_TREE_MODEL (full_store), &iter, 0,
                             &str_data, -1);
-        normalized_str_data = g_utf8_normalize (str_data, -1, G_NORMALIZE_ALL);
+        normalized_str_data = g_utf8_normalize (str_data, -1, G_NORMALIZE_NFC);
 
         if (g_regex_match (regex, normalized_str_data, 0, NULL))
         {
@@ -638,7 +705,9 @@ gnc_combo_cell_modify_verify (BasicCell* _cell,
             *start_selection = *end_selection = *cursor_position;
             return;
         }
-        match_str = quickfill_match (box->qf, newval);
+
+        if (!box->use_type_ahead_only) // Do we only want to use type-ahead
+            match_str = quickfill_match (box->qf, newval);
 
         if (match_str != NULL) // Do we have a quickfill match
         {
@@ -861,6 +930,19 @@ gnc_combo_cell_direct_update (BasicCell* bcell,
     return TRUE;
 }
 
+void
+gnc_combo_cell_use_type_ahead_only (ComboCell* cell)
+{
+    PopBox* box;
+
+    if (cell == NULL) return;
+
+    box = cell->cell.gui_private;
+
+    box->use_type_ahead_only = TRUE;
+
+}
+
 static void
 gnc_combo_cell_gui_realize (BasicCell* bcell, gpointer data)
 {
