@@ -21,11 +21,8 @@
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
-extern "C"
-{
 #include <config.h>
 #include <qof.h>
-}
 #include <sstream>
 #include <iomanip>
 #include <gnc-datetime.hpp>
@@ -102,9 +99,11 @@ GncSqlColumnTableEntry::add_objectref_guid_to_query (QofIdTypeConst obj_name,
     auto inst = get_row_value_from_object<QofInstance*>(obj_name, pObject);
     if (inst == nullptr) return;
     auto guid = qof_instance_get_guid (inst);
-    if (guid != nullptr)
-        vec.emplace_back (std::make_pair (std::string{m_col_name},
-                                          quote_string(guid_to_string(guid))));
+    if (guid != nullptr) {
+        gchar *guid_s = guid_to_string(guid);
+        vec.emplace_back (std::make_pair (std::string{m_col_name}, quote_string(guid_s)));
+        g_free(guid_s);
+    }
 }
 
 void
@@ -326,7 +325,6 @@ GncSqlColumnTableEntryImpl<CT_GUID>::load (const GncSqlBackend* sql_be,
 {
 
     GncGUID guid;
-    const GncGUID* pGuid;
 
     g_return_if_fail (pObject != NULL);
     g_return_if_fail (m_gobj_param_name != nullptr || get_setter(obj_name) != nullptr);
@@ -360,9 +358,9 @@ GncSqlColumnTableEntryImpl<CT_GUID>::add_to_query(QofIdTypeConst obj_name,
 
     if (s != nullptr)
     {
-
-        vec.emplace_back (std::make_pair (std::string{m_col_name},
-                                          quote_string(guid_to_string(s))));
+        gchar *guid_s = guid_to_string(s);
+        vec.emplace_back (std::make_pair (std::string{m_col_name}, quote_string(guid_s)));
+        g_free(guid_s);
         return;
     }
 }
@@ -677,8 +675,6 @@ gnc_sql_load_object (const GncSqlBackend* sql_be, GncSqlRow& row,
                      QofIdTypeConst obj_name, gpointer pObject,
                      const EntryVec& table)
 {
-    QofSetterFunc setter;
-
     g_return_if_fail (sql_be != NULL);
     g_return_if_fail (pObject != NULL);
 
