@@ -31,7 +31,6 @@
 #include <glib/gprintf.h>
 #include <glib/gstdio.h>
 
-extern "C" {
 #include <config.h>
 
 #include <platform.h>
@@ -63,11 +62,11 @@ extern "C" {
 #ifdef MAC_INTEGRATION
 #include <Foundation/Foundation.h>
 #endif
-}
 
 #include "gnc-locale-utils.hpp"
 #include <boost/filesystem.hpp>
 #include <boost/locale.hpp>
+#include <regex>
 #include <iostream>
 #include <numeric>
 
@@ -212,7 +211,10 @@ gchar *gnc_file_path_relative_part (const gchar *prefix, const gchar *path)
 {
     std::string p{path};
     if (p.find(prefix) == 0)
-        return g_strdup(p.substr(strlen(prefix)).c_str());
+    {
+        auto str = p.substr(strlen(prefix));
+        return g_strdup(str.c_str());
+    }
     return g_strdup(path);
 }
 
@@ -502,7 +504,6 @@ get_user_data_dir ()
 static bfs::path
 get_user_data_dir()
 {
-    char *retval = NULL;
     NSFileManager*fm = [NSFileManager defaultManager];
     NSArray* appSupportDir = [fm URLsForDirectory:NSApplicationSupportDirectory
     inDomains:NSUserDomainMask];
@@ -586,7 +587,6 @@ get_userconfig_home(void)
 
 static std::string migrate_gnc_datahome()
 {
-    auto success = false;
     // Specify location of dictionaries
     bfs::path old_dir(g_get_home_dir(), cvt);
     old_dir /= ".gnucash";
@@ -703,7 +703,7 @@ static std::string migrate_gnc_datahome()
                                          % gnc_userconfig_home.string().c_str();
 
         migration_msg << std::endl;
-        for (auto success_file : succeeded)
+        for (const auto& success_file : succeeded)
             migration_msg << "- " << success_file << std::endl;
     }
     if (!conf_exist_vec.empty())
@@ -713,7 +713,7 @@ static std::string migrate_gnc_datahome()
                                         "The following files have become obsolete and will be ignored:",
                                         conf_exist_vec.size())
                       << std::endl;
-        for (auto obs_file : conf_exist_vec)
+        for (const auto& obs_file : conf_exist_vec)
             migration_msg << "- " << obs_file << std::endl;
     }
     if (!failed.empty())
@@ -723,7 +723,7 @@ static std::string migrate_gnc_datahome()
                                                     "The following files could not be moved to {1}:",
                                                           failed.size())}) % gnc_userconfig_home.string().c_str()
                       << std::endl;
-        for (auto failed_file : failed)
+        for (const auto& failed_file : failed)
             migration_msg << "- " << failed_file << std::endl;
     }
 
@@ -1330,4 +1330,21 @@ gnc_list_all_paths (void)
     return std::accumulate (paths.rbegin(), paths.rend(), (GList*) nullptr, accum);
 }
 
+static const std::regex
+backup_regex (".*[.](?:xac|gnucash)[.][0-9]{14}[.](?:xac|gnucash)$");
+
+gboolean gnc_filename_is_backup (const char *filename)
+{
+    return std::regex_match (filename, backup_regex);
+}
+
+static const std::regex
+datafile_regex (".*[.](?:xac|gnucash)$");
+
+gboolean gnc_filename_is_datafile (const char *filename)
+{
+    return !gnc_filename_is_backup (filename) &&
+        std::regex_match (filename, datafile_regex);
+}
+
 /* =============================== END OF FILE ========================== */
